@@ -89,7 +89,8 @@ impl VisitMut for AssertValid {
     }
 }
 
-#[testing::fixture("../swc_ecma_parser/tests/typescript/**/input.ts")]
+#[testing::fixture("../swc_ecma_parser/tests/tsc/**/*.ts")]
+#[testing::fixture("../swc_ecma_parser/tests/typescript/**/*.ts")]
 #[testing::fixture("../swc/tests/tsc-references/**/*.js")]
 fn assert_no_invalid(input: PathBuf) {
     testing::run_test(false, |cm, _handler| {
